#####################################
pymemtrace's documentation
#####################################

Contents:

.. toctree::
    :maxdepth: 2

    readme
    installation
    examples
    technical_notes

    memory_leaks
    reference

    contributing
    authors
    history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
